unit ADCU;
{ ADICOM Praha, Michal Bures }
interface

procedure ADCInit(IOAddr:Word);
(* NASTAVI BAZOVOU ADRESU PREVODNIKU
   IOaddr = Adresa desky v rozsahu $300 .. $31C s krokem 4
   ADC1216W.DLL index 1
   *)

function ADCRead(Channel:Byte):Word;
(* VRACI PREVEDENE CISLO INTEGER
   chanel = 0 .. 15
   returns: 0 .. maxint prevedena hodnota
   ADC1216W.DLL index 2
   *)

function IORead:Byte;
(* vraci stav digitalniho vstupu
   ADC1216W.DLL index 3
   *)

procedure IOWrite(Value:Byte);
(* zapis na digitalni porty
   ADC1216W.DLL index 4
   *)

procedure ADCExtInit(AMinValue,AMaxValue:Real);
(* Inicializace procedury GetVoltage
   MinValue a MaxValue urcuji rozsah napeti
   ADC1216W.DLL index 5
   *)

function GetVoltage(Channel:Byte):Real;
(* Provede precteni udaju z kanalu a nasledne prepocte a vrati napeti
   ADC1216W.DLL index 6
   *)

function ADCQuickRead(Channel:Byte):Word;
(* VRACI PREVEDENE CISLO INTEGER V NIZKEM ROZLISENI (8bit)
   chanel = 0 .. 15
   returns: 0 .. MaxInt prevedena hodnota
   ADC1216W.DLL index 7
   *)

procedure DACWrite(Value:Word);
(* Posila kombinaci na D/A convertor
   ADC1216W.DLL index 8
   *)

implementation
{$F+}

{$IFNDEF WINDOWS}
var MinValue,MaxValue:Real;
{$ENDIF}

procedure ADCInit(IOAddr:Word);
{$IFDEF WINDOWS}
external 'ADC1216W' index 1;
{$ELSE}
external;
{$ENDIF}

{$IFNDEF WINDOWS}
function ADCReadProc(Channel:Byte;Resolution:Word):Word;external;
{$ENDIF}

function ADCRead(Channel:Byte):Word;
{$IFDEF WINDOWS}
external 'ADC1216W' index 2;
{$ELSE}
  begin
    ADCRead:=ADCReadProc(Channel,12);
  end;
{$ENDIF}

function IORead:Byte;
{$IFDEF WINDOWS}
external 'ADC1216W' index 3;
{$ELSE}
external;
{$ENDIF}

procedure IOWrite(Value:Byte);
{$IFDEF WINDOWS}
external 'ADC1216W' index 4;
{$ELSE}
external;
{$ENDIF}

procedure ADCExtInit(AMinValue,AMaxValue:Real);
{$IFDEF WINDOWS}
external 'ADC1216W' index 5;
{$ELSE}
  begin
    MinValue:=AMinValue;
    MaxValue:=AMaxValue;
  end;
{$ENDIF}

function GetVoltage(Channel:Byte):Real;
{$IFDEF WINDOWS}
external 'ADC1216W' index 6;
{$ELSE}
  begin
    GetVoltage:=(MaxValue-MinValue)/4096*(ADCRead(Channel)+1)+MinValue;
  end;
{$ENDIF}

function ADCQuickRead(Channel:Byte):Word;
{$IFDEF WINDOWS}
external 'ADC1216W' index 7;
{$ELSE}
  begin
    ADCQuickRead:=ADCReadProc(Channel,8);
  end;
{$ENDIF}

procedure DACWrite(Value:Word);
{$IFDEF WINDOWS}
external 'ADC1216W' index 8;
{$ELSE}
external;
{$ENDIF}

{$IFNDEF WINDOWS}
{$L ADC12_P.OBJ}
{$ENDIF}

end.
